An object to create a new AlignedTextGrid which can be one of: i) A path-like value (str|pathlib.Path) to a TextGrid file. ii) A praatio.textgrid.TextGrid object. iii) A list of TierGroups
If a single list of SequenceInterval subclasses is given, they will be repeated as many times as necessary to assign a class to every tier. So if there are three speakers, each with a word and phone tier, [Word, Phone] will process them each into a tier group. If your TextGrids are more complex, provide a nested list with the class for each tier within each tier group. Say, if only the first speaker had both a word and phone tier, and the remaining two had only a word tier, [[Word, Phone], [Word], [Word]]
[SequenceInterval]
Attributes
Name
Type
Description
entry_classes
list[Sequence[Type[SequenceInterval]]] | list[]
The entry classes for each tier within a tier group.
If any tiers have time gaps between intervals, missing subset or superset intervals or TierGroups with different start and ent times, this will clean them up by adding intervals with a blank label.