Bottom
sequences.sequences.Bottom()A bottom level interval class
This is a special subclass intended to be the subset_class for classes at the bottom of the hierarchy.
Reuse
GPLv3
A bottom level interval class
This is a special subclass intended to be the subset_class for classes at the bottom of the hierarchy.