PointsGroup
points.tiers.PointsGroup(tiers=[SequencePointTier()])
A collection of point tiers PointsGroups have all the same methods and attributes as TierGroupMixins and WithinMixins
Methods
get_nearest_points_index
points.tiers.PointsGroup.get_nearest_points_index(time)
Get indicies of nearest point
Parameters
| time |
float |
time from which the nearest index should be returned. |
required |
Returns
| list |
list |
A list of indices |
shift
points.tiers.PointsGroup.shift(increment)
Shift the times of all points within the PointsGroup by the increment size
Parameters
| increment |
float |
The time increment by which to shift the points within the PointsGroup. Could be positive or negative |
required |