Top
sequences.sequences.Top()A top level interval class
This is a special subclass intended to be the superset_class for classes at the top of the hierarchy.
Reuse
GPLv3
A top level interval class
This is a special subclass intended to be the superset_class for classes at the top of the hierarchy.